@@ -82,49 +82,51 @@ Puppet::Type.newtype(:nova_flavor) do
     end
   end
 
-  newparam(:id) do
+  newproperty(:id) do
     desc 'Unique ID (integer or UUID) for the flavor.'
   end
 
-  newparam(:ram) do
+  newproperty(:ram) do
     desc 'Amount of RAM to use (in megabytes).'
+    newvalues(/\d+/)
   end
 
-  newparam(:disk) do
+  newproperty(:disk) do
     desc 'Amount of disk space (in gigabytes) to use for the root (/) partition.'
+    newvalues(/\d+/)
   end
 
-  newparam(:vcpus) do
+  newproperty(:vcpus) do
     desc 'Number of virtual CPUs to use.'
+    newvalues(/\d+/)
   end
 
-  newparam(:ephemeral) do
+  newproperty(:ephemeral) do
     desc 'Amount of disk space (in gigabytes) to use for the ephemeral partition.'
+    newvalues(/\d+/)
   end
 
-  newparam(:swap) do
+  newproperty(:swap) do
     desc 'Amount of swap space (in megabytes) to use.'
+    newvalues(/\d+/)
   end
 
-  newparam(:rxtx_factor) do
+  newproperty(:rxtx_factor) do
     desc 'The slice of bandwidth that the instances with this flavor can use (through the Virtual Interface (vif) creation in the hypervisor)'
+    newvalues(/\d+(\.\d+)?/)
   end
 
-  newparam(:is_public) do
+  newproperty(:is_public) do
     desc "Whether the flavor is public or not. Default true"
     newvalues(/(y|Y)es/, /(n|N)o/, /(t|T)rue/, /(f|F)alse/, true, false)
-    defaultto(true)
-    munge do |v|
-      if v.is_a?(String)
-        if v =~ /^(y|Y)es$/
-          :true
-        elsif v =~ /^(n|N)o$/
-          :false
-        else
-          v.to_s.downcase.to_sym
-        end
+    defaultto(:true)
+
+    munge do |value|
+      case value.to_s.downcase
+      when 'true', 'yes'
+        :true
       else
-        v.to_s.downcase.to_sym
+        :false
       end
     end
   end
@@ -140,23 +142,11 @@ Puppet::Type.newtype(:nova_flavor) do
   newproperty(:properties) do
     desc "The set of flavor properties"
 
-    munge do |value|
-      return value if value.is_a? Hash
-
-      # wrap property value in commas
-      value.gsub!(/=(\w+)/, '=\'\1\'')
-      Hash[value.scan(/(\S+)='([^']*)'/)]
-    end
-
     validate do |value|
       if value.is_a?(Hash)
         return true
-      elsif value.is_a?(String)
-        value.split(',').each do |property|
-          raise ArgumentError, "Key/value pairs should be separated by an =" unless property.include?('=')
-        end
       else
-        raise ArgumentError, "Invalid properties #{value}. Requires a String or a Hash, not a #{value.class}"
+        raise ArgumentError, "Invalid properties #{value}. Requires a Hash, not a #{value.class}"
       end
     end
   end
