@@ -45,7 +45,9 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/file_backed_memory').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/images_type').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/volume_enforce_multipath').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/num_volume_scan_tries').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/nfs_mount_point_base').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value('<SERVICE DEFAULT>')}
@@ -89,7 +91,9 @@ describe 'nova::compute::libvirt' do
           :file_backed_memory            => 2048,
           :images_type                   => 'raw',
           :volume_use_multipath          => false,
+          :volume_enforce_multipath      => false,
           :num_volume_scan_tries         => 3,
+          :nfs_mount_point_base          => '/var/lib/nova/mnt',
           :nfs_mount_options             => 'rw,intr,nolock',
           :num_pcie_ports                => 16,
           :mem_stats_period_seconds      => 20,
@@ -138,7 +142,9 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/file_backed_memory').with_value(2048)}
       it { is_expected.to contain_nova_config('libvirt/images_type').with_value('raw')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value(false)}
+      it { is_expected.to contain_nova_config('libvirt/volume_enforce_multipath').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/num_volume_scan_tries').with_value(3)}
+      it { is_expected.to contain_nova_config('libvirt/nfs_mount_point_base').with_value('/var/lib/nova/mnt')}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('rw,intr,nolock')}
       it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_value(16)}
       it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value(20)}
