@@ -50,6 +50,18 @@ describe 'nova::compute::libvirt::virtproxyd' do
       it { is_expected.to contain_virtproxyd_config('ovs_timeout').with_value(params[:ovs_timeout])}
       it { is_expected.to contain_virtproxyd_config('tls_priority').with_value(params[:tls_priority]).with_quote(true)}
     end
+
+    context 'with array values' do
+      let :params do
+        {
+          :log_outputs => ['3:syslog', '3:stderr'],
+          :log_filters => ['1:logging', '4:object', '4:json', '4:event', '1:util'],
+        }
+      end
+
+      it { is_expected.to contain_virtproxyd_config('log_outputs').with_value('3:syslog 3:stderr').with_quote(true)}
+      it { is_expected.to contain_virtproxyd_config('log_filters').with_value('1:logging 4:object 4:json 4:event 1:util').with_quote(true)}
+    end
   end
 
   on_supported_os({
