@@ -22,10 +22,10 @@ describe 'nova::compute::pci' do
       end
     end
 
-    context 'with passthrough array' do
+    context 'with device_specs array' do
       let :params do
         {
-            :passthrough => [
+          :device_specs => [
             {
               "vendor_id"  => "8086",
               "product_id" => "0126"
@@ -45,36 +45,10 @@ describe 'nova::compute::pci' do
       end
     end
 
-    context 'with passthrough JSON encoded string' do
+    context 'when device_specs is empty' do
       let :params do
         {
-          :passthrough => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]",
-        }
-      end
-
-      it 'configures nova pci device_spec entries' do
-        is_expected.to contain_nova_config('pci/device_spec').with(
-          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
-        )
-      end
-    end
-
-    context 'when passthrough is empty' do
-      let :params do
-        {
-          :passthrough => []
-        }
-      end
-
-      it 'clears pci device_spec configuration' do
-        is_expected.to contain_nova_config('pci/device_spec').with(:value => '<SERVICE DEFAULT>')
-      end
-    end
-
-    context 'when passthrough is empty string' do
-      let :params do
-        {
-          :passthrough => ""
+          :device_specs => []
         }
       end
 
