@@ -25,10 +25,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
       end
 
-      it 'does not configure auth_strategy' do
-        is_expected.to contain_nova_config('api/auth_strategy').with_value('<SERVICE DEFAULT>')
-      end
-
       it 'configures rabbit' do
         is_expected.to contain_oslo__messaging__default('nova_config').with(
           :executor_thread_pool_size => '<SERVICE DEFAULT>',
@@ -40,11 +36,11 @@ describe 'nova' do
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
           :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :amqp_auto_delete                => '<SERVICE DEFAULT>',
           :kombu_compression               => '<SERVICE DEFAULT>',
           :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
           :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
@@ -53,9 +49,12 @@ describe 'nova' do
           :rabbit_ha_queues                => '<SERVICE DEFAULT>',
           :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
           :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+          :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :use_queue_manager               => '<SERVICE DEFAULT>',
+          :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
           :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
           :rabbit_retry_interval           => '<SERVICE DEFAULT>',
         )
@@ -86,13 +85,16 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/initial_cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/initial_ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/initial_disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/record').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/source_is_ipv6').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/cell_worker_thread_pool_size').with_value('<SERVICE DEFAULT>')
       end
 
     end
@@ -109,10 +111,10 @@ describe 'nova' do
           :rabbit_use_ssl                     => true,
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
-          :rabbit_heartbeat_in_pthread        => true,
           :rabbit_qos_prefetch_count          => 0,
           :kombu_reconnect_delay              => '5.0',
           :amqp_durable_queues                => true,
+          :amqp_auto_delete                   => true,
           :kombu_compression                  => 'gzip',
           :kombu_ssl_ca_certs                 => '/etc/ca.cert',
           :kombu_ssl_certfile                 => '/etc/certfile',
@@ -121,15 +123,17 @@ describe 'nova' do
           :rabbit_ha_queues                   => true,
           :rabbit_quorum_queue                => true,
           :rabbit_transient_quorum_queue      => true,
+          :rabbit_transient_queues_ttl        => 60,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_use_queue_manager           => true,
+          :rabbit_stream_fanout               => true,
           :rabbit_enable_cancel_on_failover   => false,
           :rabbit_retry_interval              => '1',
           :lock_path                          => '/var/locky/path',
           :state_path                         => '/var/lib/nova2',
           :service_down_time                  => '60',
-          :auth_strategy                      => 'foo',
           :ensure_package                     => '2012.1.1-15.el6',
           :host                               => 'test-001.example.org',
           :notification_transport_url         => 'rabbit://rabbit_user:password@localhost:5673',
@@ -145,13 +149,16 @@ describe 'nova' do
           :upgrade_level_scheduler            => '1.0.0',
           :purge_config                       => false,
           :my_ip                              => '192.0.2.1',
+          :record                             => '/var/lib/nova/novnc.log',
           :ssl_only                           => true,
+          :source_is_ipv6                     => false,
           :cert                               => '/etc/ssl/private/snakeoil.pem',
           :key                                => '/etc/ssl/certs/snakeoil.pem',
           :console_ssl_ciphers                => 'kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES',
           :console_ssl_minimum_version        => 'tlsv1_2',
           :dhcp_domain                        => 'foo',
           :instance_name_template             => 'instance-%08x',
+          :cell_worker_thread_pool_size       => 5,
         }
       end
 
@@ -169,10 +176,6 @@ describe 'nova' do
         })
       end
 
-      it 'configures auth_strategy' do
-        is_expected.to contain_nova_config('api/auth_strategy').with_value('foo')
-      end
-
       it 'configures rabbit' do
         is_expected.to contain_oslo__messaging__default('nova_config').with(
           :executor_thread_pool_size => 64,
@@ -184,10 +187,10 @@ describe 'nova' do
           :rabbit_use_ssl                  => true,
           :heartbeat_timeout_threshold     => '60',
           :heartbeat_rate                  => '10',
-          :heartbeat_in_pthread            => true,
           :rabbit_qos_prefetch_count       => 0,
           :kombu_reconnect_delay           => '5.0',
           :amqp_durable_queues             => true,
+          :amqp_auto_delete                => true,
           :kombu_compression               => 'gzip',
           :kombu_ssl_ca_certs              => '/etc/ca.cert',
           :kombu_ssl_certfile              => '/etc/certfile',
@@ -196,9 +199,12 @@ describe 'nova' do
           :rabbit_ha_queues                => true,
           :rabbit_quorum_queue             => true,
           :rabbit_transient_quorum_queue   => true,
+          :rabbit_transient_queues_ttl     => 60,
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
+          :use_queue_manager               => true,
+          :rabbit_stream_fanout            => true,
           :enable_cancel_on_failover       => false,
           :rabbit_retry_interval           => '1',
         )
@@ -235,13 +241,16 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/periodic_fuzzy_delay').with_value('61')
         is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
         is_expected.to contain_nova_config('DEFAULT/long_rpc_timeout').with_value('1800')
+        is_expected.to contain_nova_config('DEFAULT/record').with_value('/var/lib/nova/novnc.log')
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
+        is_expected.to contain_nova_config('DEFAULT/source_is_ipv6').with_value(false)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('/etc/ssl/private/snakeoil.pem')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES')
         is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('tlsv1_2')
         is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('foo')
         is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('instance-%08x');
+        is_expected.to contain_nova_config('DEFAULT/cell_worker_thread_pool_size').with_value(5);
       end
 
       context 'with multiple notification_driver' do
@@ -311,53 +320,6 @@ describe 'nova' do
       end
     end
 
-    context 'with SSL socket options set' do
-      let :params do
-        {
-          :use_ssl          => true,
-          :enabled_ssl_apis => ['osapi_compute'],
-          :cert_file        => '/path/to/cert',
-          :ca_file          => '/path/to/ca',
-          :key_file         => '/path/to/key',
-        }
-      end
-
-      it { is_expected.to contain_nova_config('DEFAULT/enabled_ssl_apis').with_value('osapi_compute') }
-      it { is_expected.to contain_nova_config('wsgi/ssl_ca_file').with_value('/path/to/ca') }
-      it { is_expected.to contain_nova_config('wsgi/ssl_cert_file').with_value('/path/to/cert') }
-      it { is_expected.to contain_nova_config('wsgi/ssl_key_file').with_value('/path/to/key') }
-    end
-
-    context 'with SSL socket options set with wrong parameters' do
-      let :params do
-        {
-          :use_ssl          => true,
-          :enabled_ssl_apis => ['osapi_compute'],
-          :ca_file          => '/path/to/ca',
-          :key_file         => '/path/to/key',
-        }
-      end
-
-      it_raises 'a Puppet::Error', /The cert_file parameter is required when use_ssl is set to true/
-    end
-
-    context 'with SSL socket options set to false' do
-      let :params do
-        {
-          :use_ssl          => false,
-          :enabled_ssl_apis => [],
-          :cert_file        => false,
-          :ca_file          => false,
-          :key_file         => false,
-        }
-      end
-
-      it { is_expected.to contain_nova_config('DEFAULT/enabled_ssl_apis').with_ensure('absent') }
-      it { is_expected.to contain_nova_config('wsgi/ssl_ca_file').with_ensure('absent') }
-      it { is_expected.to contain_nova_config('wsgi/ssl_cert_file').with_ensure('absent') }
-      it { is_expected.to contain_nova_config('wsgi/ssl_key_file').with_ensure('absent') }
-    end
-
     context 'with allocation ratios set' do
       let :params do
         {
