@@ -15,6 +15,7 @@ describe 'nova::keystone::auth' do
         :configure_user      => true,
         :configure_user_role => true,
         :configure_endpoint  => true,
+        :configure_service   => true,
         :service_name        => 'nova',
         :service_type        => 'compute',
         :service_description => 'OpenStack Compute Service',
@@ -23,7 +24,7 @@ describe 'nova::keystone::auth' do
         :password            => 'nova_password',
         :email               => 'nova@localhost',
         :tenant              => 'services',
-        :roles               => ['admin'],
+        :roles               => ['admin', 'service'],
         :system_scope        => 'all',
         :system_roles        => [],
         :public_url          => 'http://127.0.0.1:8774/v2.1',
@@ -41,11 +42,12 @@ describe 'nova::keystone::auth' do
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
+          :configure_service   => false,
           :service_description => 'Alternative OpenStack Compute Service',
           :service_name        => 'alt_service',
           :service_type        => 'alt_compute',
           :region              => 'RegionTwo',
-          :roles               => ['admin', 'service'],
+          :roles               => ['admin'],
           :system_scope        => 'alt_all',
           :system_roles        => ['admin', 'member', 'reader'],
           :public_url          => 'https://10.10.10.10:80',
@@ -57,6 +59,7 @@ describe 'nova::keystone::auth' do
         :configure_user      => false,
         :configure_user_role => false,
         :configure_endpoint  => false,
+        :configure_service   => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_compute',
         :service_description => 'Alternative OpenStack Compute Service',
@@ -65,7 +68,7 @@ describe 'nova::keystone::auth' do
         :password            => 'nova_password',
         :email               => 'alt_nova@alt_localhost',
         :tenant              => 'alt_service',
-        :roles               => ['admin', 'service'],
+        :roles               => ['admin'],
         :system_scope        => 'alt_all',
         :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
