@@ -9,7 +9,7 @@ describe 'nova::placement' do
       :region_name         => 'RegionOne',
       :username            => 'placement',
       :user_domain_name    => 'Default',
-      :auth_url            => 'http://127.0.0.1:5000/v3',
+      :auth_url            => 'http://127.0.0.1:5000',
     }
   end
 
@@ -44,7 +44,7 @@ describe 'nova::placement' do
           :valid_interfaces    => 'internal,public',
           :username            => 'placement2',
           :user_domain_name    => 'default',
-          :auth_url            => 'https://127.0.0.1:5000/v3',
+          :auth_url            => 'http://127.0.0.1:5000/v3',
         )
       end
 
