@@ -36,6 +36,7 @@ describe 'nova::wsgi::apache_api' do
         :access_log_pipe             => nil,
         :access_log_syslog           => nil,
         :access_log_format           => nil,
+        :access_log_env_var          => nil,
         :error_log_file              => nil,
         :error_log_pipe              => nil,
         :error_log_syslog            => nil,
@@ -118,16 +119,18 @@ describe 'nova::wsgi::apache_api' do
 
       let :params do
         {
-          :access_log_format => 'foo',
-          :access_log_syslog => 'syslog:local0',
-          :error_log_syslog  => 'syslog:local1',
+          :access_log_format  => 'foo',
+          :access_log_syslog  => 'syslog:local0',
+          :error_log_syslog   => 'syslog:local1',
+          :access_log_env_var => '!dontlog',
         }
       end
 
       it { should contain_openstacklib__wsgi__apache('nova_api_wsgi').with(
-        :access_log_format => params[:access_log_format],
-        :access_log_syslog => params[:access_log_syslog],
-        :error_log_syslog  => params[:error_log_syslog],
+        :access_log_format  => params[:access_log_format],
+        :access_log_syslog  => params[:access_log_syslog],
+        :error_log_syslog   => params[:error_log_syslog],
+        :access_log_env_var => params[:access_log_env_var],
       )}
     end
 
@@ -240,7 +243,7 @@ describe 'nova::wsgi::apache_api' do
         when 'RedHat'
           {
             :wsgi_script_path       => '/var/www/cgi-bin/nova',
-            :api_wsgi_script_source => '/usr/bin/nova-api-wsgi',
+            :api_wsgi_script_source => '/usr/lib/python3.9/site-packages/nova/wsgi/osapi_compute.py',
           }
         end
       end
