@@ -13,9 +13,6 @@ RSpec.configure do |c|
   c.alias_it_should_behave_like_to :it_raises, 'raises'
 
   c.module_path = File.join(fixture_path, 'modules')
-  c.manifest_dir = File.join(fixture_path, 'manifests')
-
-  c.mock_with :rspec
 end
 
 at_exit { RSpec::Puppet::Coverage.report! }
