@@ -164,24 +164,24 @@ domain_id="domain_one_id"
         expect(instances[0].disk).to eq('2')
         expect(instances[0].ephemeral).to eq('0')
         expect(instances[0].vcpus).to eq('1')
-        expect(instances[0].is_public).to eq(true)
+        expect(instances[0].is_public).to eq(:true)
         expect(instances[0].swap).to eq('0')
         expect(instances[0].rxtx_factor).to eq('1.0')
         expect(instances[0].properties).to eq({})
-        expect(instances[0].project).to eq('')
-        expect(instances[0].project_name).to eq('')
+        expect(instances[0].project).to eq(:absent)
+        expect(instances[0].project_name).to eq(:absent)
         expect(instances[1].name).to eq('m1.nano')
         expect(instances[1].id).to eq('42')
         expect(instances[1].ram).to eq('256')
         expect(instances[1].disk).to eq('2')
         expect(instances[1].ephemeral).to eq('0')
         expect(instances[1].vcpus).to eq('1')
-        expect(instances[1].is_public).to eq(false)
+        expect(instances[1].is_public).to eq(:false)
         expect(instances[1].swap).to eq('0')
         expect(instances[1].rxtx_factor).to eq('1.0')
         expect(instances[1].properties).to eq({'key1' => 'val1', 'key2' => 'val2'})
-        expect(instances[1].project).to eq('')
-        expect(instances[1].project_name).to eq('')
+        expect(instances[1].project).to eq(:absent)
+        expect(instances[1].project_name).to eq(:absent)
       end
     end
 
